@@ -13,25 +13,12 @@
 //#include <QtOpenGL/QGLWidget>
 //#endif
 
-static QNetworkCookieJar *jar = new QNetworkCookieJar();
-
-class MyNetworkAccessManagerFactory : public QDeclarativeNetworkAccessManagerFactory
-{
-public:
-    virtual QNetworkAccessManager *create(QObject *parent);
-};
-
-QNetworkAccessManager *MyNetworkAccessManagerFactory::create(QObject *parent = 0)
-{
-    QNetworkAccessManager *nam = new QNetworkAccessManager(parent);
-
-    nam->setCookieJar(jar);
-    return nam;
-}
-
-
 int main(int argc, char *argv[])
 {
+#ifdef Q_WS_MAEMO_5
+    QApplication::setApplicationName(QString("FMRadio"));
+#endif
+
     QApplication app(argc, argv);   
     Controller ct;
     YouTube yt;
@@ -59,8 +46,7 @@ int main(int argc, char *argv[])
         Sharing sh;
         DownloadManager dm;
 
-        MyNetworkAccessManagerFactory *factory = new MyNetworkAccessManagerFactory;
-        QNetworkAccessManager *manager = factory->create();
+        QNetworkAccessManager *manager = new QNetworkAccessManager();
         yt.setNetworkAccessManager(manager);
         dm.setNetworkAccessManager(manager);
         sh.setNetworkAccessManager(manager);
@@ -72,12 +58,12 @@ int main(int argc, char *argv[])
 
         qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
-        viewer.engine()->setNetworkAccessManagerFactory(factory);
-
 #ifdef Q_WS_MAEMO_5
-//        viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
-//        viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
+        viewer.addImportPath(QString("/opt/qtm12/imports"));
+        viewer.addPluginPath(QString("/opt/qtm12/plugins"));
         viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
+//        viewer.setViewport(new QGLWidget());
+
         QDir path;
         path.setPath("/home/user/.config/cutetube");
         if (!path.exists()) {
@@ -87,7 +73,6 @@ int main(int argc, char *argv[])
         if (!path.exists()) {
             path.mkpath("/home/user/MyDocs/.cutetube");
         }
-        //        viewer.setViewport(new QGLWidget());
 
         QString locale = ct.getLanguage();
 
@@ -108,6 +93,7 @@ int main(int argc, char *argv[])
         /* Get the video URL and play the video */
 
         QString playerUrl = args.at(1);
+        QString videoId = playerUrl.split("v=").at(1).split("&").at(0);
         QString quality = "hq";
         if (args.length() > 2) {
             if (args.at(2) == "m") {
@@ -119,9 +105,9 @@ int main(int argc, char *argv[])
         QObject::connect(&yt, SIGNAL(videoUrlError()), &app, SLOT(quit()));
         QObject::connect(&ct, SIGNAL(playbackStarted(QString)), &app, SLOT(quit()));
         yt.setPlaybackQuality(quality);
-        yt.getVideoUrl(playerUrl);
+        yt.getVideoUrl(videoId);
 
-        app.exec();
+        return app.exec();
     }
     else {
         qWarning() << "Invalid arguments";
