@@ -24,7 +24,6 @@ function showPlaylistDialog() {
         playlistDialog.close.connect(closeDialogs);
         dimmer.state = "dim";
         playlistDialog.state = "show";
-        mouseArea.enabled = true;
     }
 }
 
@@ -56,7 +55,6 @@ function showAddCommentDialog() {
         commentDialog.close.connect(closeDialogs);
         dimmer.state = "dim";
         commentDialog.state = "show";
-        mouseArea.enabled = true;
     }
 }
 
@@ -65,7 +63,6 @@ function closeDialogs() {
 
     dialogClose();
     dimmer.state = "";
-    mouseArea.enabled = false;
     toggleControls(true);
 }
 
@@ -77,7 +74,6 @@ function checkFacebookAccess() {
         shareDialog.close.connect(closeDialogs);
         dimmer.state = "dim";
         shareDialog.state = "show";
-        mouseArea.enabled = true;
     }
     else {
         getFacebookAccessToken();
@@ -91,7 +87,6 @@ function getFacebookAccessToken() {
     oauthDialog.close.connect(closeDialogs);
     dimmer.state = "dim";
     oauthDialog.state = "show";
-    mouseArea.enabled = true;
 }
 
 function loadComments() {
