@@ -45,7 +45,7 @@ function showPlaylistDialog() {
             playlistDialog.state = "show";
         }
         else {
-            messages.messages.displayMessage(messages._NOT_SIGNED_IN);
+            messages.displayMessage(messages._NOT_SIGNED_IN);
         }
     }
 }
@@ -60,7 +60,7 @@ function addVideosToPlaybackQueue() {
             playVideos(list);
         }
         else {
-            messages.messages.displayMessage(messages._USE_CUTETUBE_PLAYER);
+            messages.displayMessage(messages._USE_CUTETUBE_PLAYER);
         }
         videoList.checkList = [];
     }
@@ -102,7 +102,7 @@ function deleteVideosFromPlaylist() {
         }
     }
     else {
-        messages.messages.displayMessage(messages._NOT_SIGNED_IN);
+        messages.displayMessage(messages._NOT_SIGNED_IN);
     }
     videoList.checkList = [];
 }
@@ -118,7 +118,7 @@ function addVideosToFavourites() {
         }
     }
     else {
-        messages.messages.displayMessage(messages._NOT_SIGNED_IN);
+        messages.displayMessage(messages._NOT_SIGNED_IN);
     }
     videoList.checkList = [];
 }
@@ -134,7 +134,7 @@ function deleteVideosFromFavourites() {
         }
     }
     else {
-        messages.messages.displayMessage(messages._NOT_SIGNED_IN);
+        messages.displayMessage(messages._NOT_SIGNED_IN);
     }
     videoList.checkList = [];
 }
@@ -168,7 +168,7 @@ function setSubscription() {
         }
     }
     else {
-        messages.messages.displayMessage(messages._NOT_SIGNED_IN);
+        messages.displayMessage(messages._NOT_SIGNED_IN);
     }
     closeDialogs();
 }
